@@ -68,7 +68,7 @@ def browser(request):
     return name
 
 
-def pytest_addoption_base(parser):
+def addoption_base(parser):
     "Method to add the option to ini."
     try:
         parser.addini("rp_uuid", 'help', type="pathlist")
